classSourceUris static method

Map<String, String> classSourceUris()

Returns a map of class names to their canonical source URIs.

Used for deduplication when the same class is exported through multiple barrels (e.g., tom_core_kernel and tom_core_server).

Implementation

static Map<String, String> classSourceUris() {
  return {
    'RestoreFileException': 'package:dcli_core/src/functions/backup.dart',
    'BackupFileException': 'package:dcli_core/src/functions/backup.dart',
    'CatException': 'package:dcli_core/src/functions/cat.dart',
    'CopyException': 'package:dcli_core/src/functions/copy.dart',
    'CreateDirException': 'package:dcli_core/src/functions/create_dir.dart',
    'DCliFunction': 'package:dcli_core/src/functions/dcli_function.dart',
    'DCliFunctionException': 'package:dcli_core/src/functions/dcli_function.dart',
    'DeleteException': 'package:dcli_core/src/functions/delete.dart',
    'DeleteDirException': 'package:dcli_core/src/functions/delete_dir.dart',
    'Env': 'package:dcli_core/src/functions/env.dart',
    'Find': 'package:dcli_core/src/functions/find.dart',
    'FindItem': 'package:dcli_core/src/functions/find.dart',
    'MoveException': 'package:dcli_core/src/functions/move.dart',
    'MoveDirException': 'package:dcli_core/src/functions/move_dir.dart',
    'MoveTreeException': 'package:dcli_core/src/functions/move_tree.dart',
    'DCliException': 'package:dcli_core/src/util/dcli_exception.dart',
    'RunException': 'package:dcli_core/src/util/run_exception.dart',
    'StackList': 'package:dcli_core/src/util/stack_list.dart',
    'Ansi': 'package:dcli_terminal/src/ansi.dart',
    'AnsiColor': 'package:dcli_terminal/src/ansi_color.dart',
    'Format': 'package:dcli_terminal/src/format.dart',
    'Terminal': 'package:dcli_terminal/src/terminal.dart',
    'Ask': 'package:dcli/src/functions/ask.dart',
    'AskValidatorException': 'package:dcli/src/functions/ask.dart',
    'AskValidator': 'package:dcli/src/functions/ask.dart',
    'AskValidatorIPAddress': 'package:dcli/src/functions/ask.dart',
    'Confirm': 'package:dcli/src/functions/confirm.dart',
    'FetchData': 'package:dcli/src/functions/fetch.dart',
    'FetchUrl': 'package:dcli/src/functions/fetch.dart',
    'FetchProgress': 'package:dcli/src/functions/fetch.dart',
    'FetchException': 'package:dcli/src/functions/fetch.dart',
    'ReadException': 'package:dcli/src/functions/read.dart',
    'Progress': 'package:dcli/src/progress/progress.dart',
    'PackedResource': 'package:dcli/src/resources/packed_resource.dart',
    'Resources': 'package:dcli/src/resources/resources.dart',
    'ResourceException': 'package:dcli/src/resources/resources.dart',
    'DartProject': 'package:dcli/src/script/dart_project.dart',
    'DartProjectException': 'package:dcli/src/script/dart_project.dart',
    'TemplateNotFoundException': 'package:dcli/src/script/dart_project.dart',
    'InvalidProjectTemplateException': 'package:dcli/src/script/dart_project.dart',
    'DartScript': 'package:dcli/src/script/dart_script.dart',
    'DartSdk': 'package:dcli/src/script/dart_sdk.dart',
    'Settings': 'package:dcli/src/settings.dart',
    'Shell': 'package:dcli/src/shell/shell.dart',
    'ShellException': 'package:dcli/src/shell/shell.dart',
    'ShellDetection': 'package:dcli/src/shell/shell_detection.dart',
    'UnknownShell': 'package:dcli/src/shell/unknown_shell.dart',
    'DCliPaths': 'package:dcli/src/util/dcli_paths.dart',
    'InvalidArgumentException': 'package:dcli/src/util/exceptions.dart',
    'InvalidTemplateException': 'package:dcli/src/util/exceptions.dart',
    'InstallException': 'package:dcli/src/util/exceptions.dart',
    'ProcessSyncException': 'package:dcli/src/util/exceptions.dart',
    'FileSort': 'package:dcli/src/util/file_sort.dart',
    'Column': 'package:dcli/src/util/file_sort.dart',
    'FileSync': 'package:dcli/src/util/file_sync.dart',
    'FileNotFoundException': 'package:dcli/src/util/file_util.dart',
    'NotAFileException': 'package:dcli/src/util/file_util.dart',
    'NamedLock': 'package:dcli/src/util/named_lock.dart',
    'LockException': 'package:dcli/src/util/named_lock.dart',
    'ProcessHelper': 'package:dcli/src/util/process_helper.dart',
    'ProcessDetails': 'package:dcli/src/util/process_helper.dart',
    'PubCache': 'package:dcli/src/util/pub_cache.dart',
    'Remote': 'package:dcli/src/util/remote.dart',
    'FindProgress': 'package:dcli/src/functions/find.dart',
    'HeadProgress': 'package:dcli/src/functions/head.dart',
    'TailProgress': 'package:dcli/src/functions/tail.dart',
    'Which': 'package:dcli_core/src/functions/which.dart',
    'ScopeKey': 'package:scope/src/scope.dart',
  };
}