PathBridge class

Bridge class for path module.

Constructors

PathBridge()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

bridgeClasses() List<BridgedClass>
Returns all bridge class definitions.
bridgedEnums() List<BridgedEnumDefinition<Enum>>
Returns all bridged enum definitions.
bridgedExtensions() List<BridgedExtensionDefinition>
Returns all bridged extension definitions.
classAliases() Map<String, String>
Returns a map of type alias names to their target class names.
classSourceUris() Map<String, String>
Returns a map of class names to their canonical source URIs.
enumSourceUris() Map<String, String>
Returns a map of enum names to their canonical source URIs.
extensionSourceUris() Map<String, String>
Returns a map of extension identifiers to their canonical source URIs.
functionTypedefs() List<String>
Returns the list of function typedef names declared in this library.
getImportBlock() String
Returns the import statement needed for D4rt scripts.
globalFunctions() Map<String, NativeFunctionImpl>
Returns a map of global function names to their native implementations.
globalFunctionSignatures() Map<String, String>
Returns a map of global function names to their display signatures.
globalFunctionSourceUris() Map<String, String>
Returns a map of global function names to their canonical source URIs.
registerBridges(D4rt interpreter, String importPath) → void
Registers all bridges with an interpreter.
registerGlobalVariables(D4rt interpreter, String importPath) → void
Registers all global variables with the interpreter.
sourceLibraries() List<String>
Returns the list of canonical source library URIs.
subPackageBarrels() List<String>
Returns barrel import URIs for sub-packages discovered through re-exports.