classAliases static method

Map<String, String> classAliases()

Returns a map of type alias names to their target class names.

Type aliases like typedef MaterialStateProperty<T> = WidgetStateProperty<T> are registered so that code using the alias name can resolve to the bridged class under its canonical name.

Implementation

static Map<String, String> classAliases() {
  return {
  };
}