TomD4rtDcliBridge class

Combined bridge registration for tom_d4rt_dcli.

Constructors

TomD4rtDcliBridge()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

getImportBlock() String
Get import block for all modules.
register([D4rt? interpreter]) → void
Register all bridges with D4rt interpreter.