CliException class

Base exception for CLI operations.

Implemented types
Implementers

Constructors

CliException(String message, {String? command, StackTrace? stackTrace})
Creates a CLI exception with the given message.

Properties

command String?
The command that caused the error, if applicable.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message (inherited from D4rtException, exposed for bridging).
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point of error.
final
trackedStackTrace StackTrace?
Stack trace captured by ErrorReporter when tracking is enabled.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke() bool
Revokes this error from the ErrorReporter.
inherited
toString() String
A string representation of this object.

Operators

operator ==(Object other) bool
The equality operator.
inherited