CliRuntimeImpl class

Default implementation of CliRuntime using dart:io Platform and Directory.

Implemented types

Constructors

CliRuntimeImpl()
Creates a runtime implementation.

Properties

environment Map<String, String>
Environment variables as a map.
no setteroverride
executable String
Path to the Dart executable running this process.
no setteroverride
executableArguments List<String>
Arguments passed to the executable.
no setteroverride
hashCode int
The hash code for this object.
no setterinherited
isAndroid bool
Whether running on Android.
no setteroverride
isIOS bool
Whether running on iOS.
no setteroverride
isLinux bool
Whether running on Linux.
no setteroverride
isMacOS bool
Whether running on macOS.
no setteroverride
isWindows bool
Whether running on Windows.
no setteroverride
localHostname String
Local hostname.
no setteroverride
numberOfProcessors int
Number of processors available.
no setteroverride
operatingSystem String
Operating system name (e.g., 'linux', 'macos', 'windows').
no setteroverride
operatingSystemVersion String
Operating system version.
no setteroverride
pathSeparator String
Path separator for the current platform ('/' or '').
no setteroverride
pid int
The process ID of the current Dart VM.
no setteroverride
processDirectory String
The actual process working directory (Directory.current.path).
getter/setter pairoverride
processDirectoryObject Directory
The Directory object for the current process directory.
no setteroverride
resolvedExecutable String
The resolved path to the Dart executable.
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
script Uri
The script URI being executed.
no setteroverride
version String
The Dart version string.
no setteroverride

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited