info abstract method
Show details and suggestions for a symbol.
Maps to: info [name]
If name is null, shows general info.
If name is a package name, shows package details.
Implementation
SymbolInfo? info([String? name]);
Show details and suggestions for a symbol.
Maps to: info [name]
If name is null, shows general info.
If name is a package name, shows package details.
SymbolInfo? info([String? name]);