ExecuteResult class

Result of code execution.

Constructors

ExecuteResult({required bool success, dynamic result, String? error, StackTrace? stackTrace, int sourcesLoaded = 1})
Creates an execution result.
const
ExecuteResult.failure(String? error, {StackTrace? stackTrace})
Creates a failed result.
ExecuteResult.success(dynamic result)
Creates a successful result.
const

Properties

error String?
Error message, if execution failed.
final
hashCode int
The hash code for this object.
no setterinherited
result → dynamic
The result value, if any.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourcesLoaded int
Number of source files loaded.
final
stackTrace StackTrace?
Stack trace, if execution failed.
final
success bool
Whether execution succeeded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited