recordToSession property
Whether commands should be recorded to the active session.
Typically false for nested contexts (replay, load, script).
Implementation
final bool recordToSession;
Whether commands should be recorded to the active session.
Typically false for nested contexts (replay, load, script).
final bool recordToSession;