ImportInfo class

Information about an import.

Constructors

ImportInfo({required String path, List<String> classes = const [], List<String> enums = const [], List<String> functions = const [], List<String> variables = const []})
Creates import info.
const

Properties

classes List<String>
Class names exported by this import.
final
enums List<String>
Enum names exported by this import.
final
functions List<String>
Function names exported by this import.
final
hashCode int
The hash code for this object.
no setterinherited
path String
The import path.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
variables List<String>
Variable names exported by this import.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited