InvalidMultilineModeException class

Thrown when a method is called that is invalid in the current multiline mode.

Inheritance
Implemented types

Constructors

InvalidMultilineModeException({required String currentMode, required String attemptedMethod})
Creates an invalid multiline mode exception.

Properties

attemptedMethod String
The method that was attempted.
final
command String?
The command that caused the error, if applicable.
finalinherited
currentMode String
The current multiline mode.
final
hashCode int
The hash code for this object.
no setterinherited
message String
The error message (inherited from D4rtException, exposed for bridging).
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stackTrace StackTrace?
The stack trace at the point of error.
finalinherited
trackedStackTrace StackTrace?
Stack trace captured by ErrorReporter when tracking is enabled.
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
revoke() bool
Revokes this error from the ErrorReporter.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited