MultilineMode enum

Multiline input mode for accumulated code blocks.

Each execution context maintains its own multiline mode and buffer, allowing nested replay files with their own multiline blocks.

Inheritance
Available extensions

Values

none → const MultilineMode

Not in multiline mode - normal command execution.

script → const MultilineMode

Script mode: Accumulates code to execute with return value. Triggered by .start-script.

file → const MultilineMode

File mode: Accumulates code to execute in current environment. Triggered by .start-file.

executeNew → const MultilineMode

Execute mode: Accumulates code to execute in fresh environment. Triggered by .start-execute.

define → const MultilineMode

Define mode: Accumulates definitions (classes, functions) to persist. Triggered by .start-define.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<MultilineMode>
A constant List of the values in this enum, in order of their declaration.