ReplayException class
Error during replay file execution.
- Inheritance
-
- Object
- CliException
- ReplayException
- Implemented types
Constructors
- ReplayException(String file, int line, CliException cause)
- Creates a replay exception.
Properties
- cause → CliException
-
The underlying cause of the error.
final
- command → String?
-
The command that caused the error, if applicable.
finalinherited
- file → String
-
The file being replayed.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- line → int
-
The line number where the error occurred.
final
- message → String
-
The error message (inherited from D4rtException, exposed for bridging).
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- stackTrace → StackTrace?
-
The stack trace at the point of error.
finalinherited
- trackedStackTrace ↔ StackTrace?
-
Stack trace captured by
ErrorReporterwhen tracking is enabled.getter/setter pairinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
revoke(
) → bool -
Revokes this error from the ErrorReporter.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited