SymbolInfo class

Detailed symbol information.

Constructors

SymbolInfo({required String name, required SymbolKind kind, String? documentation, Map<String, dynamic> details = const {}})
Creates symbol info.
const

Properties

details Map<String, dynamic>
Additional details about the symbol.
final
documentation String?
Documentation for the symbol.
final
hashCode int
The hash code for this object.
no setterinherited
kind SymbolKind
The kind of symbol.
final
name String
The symbol name.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited