GuidelineInfo class

Guideline document info.

Constructors

GuidelineInfo({required String name, required String path, required String relativePath, String? category, String? description})
GuidelineInfo.fromJson(Map<String, dynamic> json)
factory

Properties

category String?
final
description String?
final
hashCode int
The hash code for this object.
no setterinherited
name String
final
path String
final
relativePath String
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited