QuestListResult class
Result of listing quests.
Constructors
-
QuestListResult({required List<
QuestInfo> quests, required int totalCount, String? activeQuestId}) -
QuestListResult.fromJson(Map<
String, dynamic> json) -
factory
Properties
- activeQuestId → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
-
quests
→ List<
QuestInfo> -
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- totalCount → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited