TerminalOptions class

Terminal options

Constructors

TerminalOptions({String? name, String? shellPath, List<String>? shellArgs, String? cwd, Map<String, String>? env})

Properties

cwd String?
final
env Map<String, String>?
final
hashCode int
The hash code for this object.
no setterinherited
name String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shellArgs List<String>?
final
shellPath String?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited