VSCodeExtensions class
Wrapper for vscode.extensions API Provides access to VS Code extensions management
Constructors
- VSCodeExtensions(VSCodeAdapter _adapter)
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
activateExtension(
String extensionId, {int timeoutSeconds = 180}) → Future< bool> - Activate extension
-
getAll(
{int timeoutSeconds = 60}) → Future< List< Extension> > - Get all extensions
-
getExtension(
String extensionId, {int timeoutSeconds = 60}) → Future< Extension?> - Get extension by ID
-
getExtensionDescription(
String extensionId, {int timeoutSeconds = 60}) → Future< String?> - Get extension description
-
getExtensionDisplayName(
String extensionId, {int timeoutSeconds = 60}) → Future< String?> - Get extension display name
-
getExtensionExports(
String extensionId, {int timeoutSeconds = 120}) → Future - Get extension export (API) - returns dynamic as it depends on extension
-
getExtensionVersion(
String extensionId, {int timeoutSeconds = 60}) → Future< String?> - Get extension version
-
isInstalled(
String extensionId, {int timeoutSeconds = 60}) → Future< bool> - Check if extension is installed
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited