DcliBridge class
Bridge class for dcli module.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
bridgeClasses(
) → List< BridgedClass> - Returns all bridge class definitions.
-
bridgeClassThunks(
) → Map< String, BridgedClass Function()> - Returns deferred factory thunks keyed by class name.
-
bridgeClassTypes(
) → Map< String, Type> - Returns native Types keyed by class name, parallel to bridgeClassThunks (Step #17). Used to register the native-type lookup thunk without building the BridgedClass.
-
bridgedEnums(
) → List< BridgedEnumDefinition< Enum> > - Returns all bridged enum definitions.
-
bridgedExtensions(
) → List< BridgedExtensionDefinition> - Returns all bridged extension definitions.
-
bridgeReExports(
) → List< ({Set< String> ? hide, Set<String> ? show, String source, String target})> -
GEN-107: Library re-exports declared by the bridged source
libraries. Each tuple mirrors a Dart
export '…'directive. Consumed byregisterBridgesviaD4rt.registerLibraryReExport(mirrored onD4rtRunnerin tom_d4rt_ast). -
classAliases(
) → Map< String, String> - Returns a map of type alias names to their target class names.
-
classSourceUris(
) → Map< String, String> - Returns a map of class names to their canonical source URIs.
-
classSupertypes(
) → Map< String, List< String> > - Returns a map of class names to their flattened (transitive) native supertype names (superclasses, interfaces and mixins).
-
enumSourceUris(
) → Map< String, String> - Returns a map of enum names to their canonical source URIs.
-
extensionSourceUris(
) → Map< String, String> - Returns a map of extension identifiers to their canonical source URIs.
-
functionTypedefs(
) → List< String> - Returns the list of function typedef names declared in this library.
-
getImportBlock(
) → String - Returns the import statement needed for D4rt scripts.
-
globalFunctions(
) → Map< String, NativeFunctionImpl> - Returns a map of global function names to their native implementations.
-
globalFunctionSignatures(
) → Map< String, String> - Returns a map of global function names to their display signatures.
-
globalFunctionSourceUris(
) → Map< String, String> - Returns a map of global function names to their canonical source URIs.
-
registerBridges(
D4rt interpreter, String importPath) → void - Registers all bridges with an interpreter.
-
registerGlobalVariables(
D4rt interpreter, String importPath) → void - Registers all global variables with the interpreter.
-
sourceLibraries(
) → List< String> - Returns the list of canonical source library URIs.
-
subPackageBarrels(
) → List< String> - Returns barrel import URIs for sub-packages discovered through re-exports.