CommandsConfig class
Command restriction configuration.
Constructors
-
CommandsConfig({required String mode, required List<
String> allowed, required List<String> blocked}) - CommandsConfig.defaults()
-
factory
- CommandsConfig.fromYaml(YamlMap yaml)
-
factory
Properties
-
allowed
→ List<
String> -
Allowed commands (for whitelist mode)
final
-
blocked
→ List<
String> -
Blocked commands (for blacklist mode or additional blocks)
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- mode → String
-
'whitelist' or 'blacklist'
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
merge(
CommandsConfig other) → CommandsConfig -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited