ReplyEntry class
Reply entry in the conversation trail.
Constructors
Properties
- comment → String
-
Optional comment from the response.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- markdown → String
-
The main markdown response.
final
-
references
→ List<
String> -
File paths referenced while forming the response.
final
-
requestedAttachments
→ List<
String> -
File paths the user explicitly requested.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited