SdkPartialAssistantMessage class final
Mirrors SDKPartialAssistantMessage (type: 'stream_event'), emitted only
when includePartialMessages is set.
- Inheritance
-
- Object
- SdkMessage
- SdkPartialAssistantMessage
Constructors
-
SdkPartialAssistantMessage(Map<
String, dynamic> raw)
Properties
-
event
→ Map<
String, dynamic> ? -
The raw streaming event payload (
event).no setter - hashCode → int
-
The hash code for this object.
no setterinherited
- parentToolUseId → String?
-
Id of the parent tool use, if any.
no setter
-
raw
→ Map<
String, dynamic> -
The full original wire JSON for this message.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sessionId → String?
-
The session id the message belongs to (
session_id).no setterinherited - type → String
-
The SDK
typediscriminator (assistant,user,result, …).no setterinherited - uuid → String?
-
The message's unique id (
uuid).no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Reproduces the original wire JSON verbatim.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited